pub enum RunMode {
One {
false_if_none: bool,
},
Daemon {
opts: DaemonOpts,
restart_for_executable_change_opts: RestartForExecutableChangeOpts,
restart_for_config_change_opts: RestartForConfigChangeOpts,
log_level_opts: LogLevelOpts,
log_level: Option<LogLevel>,
action: DaemonMode,
},
}Variants
One
Carry out a single run
Fields
Daemon
Run forever, until terminated (note: evobench uses restart-on-failures and local-time by default; the local-time setting has no effect on times in the config file, those are always parsed as local-time)
Fields
opts: DaemonOptsrestart_for_executable_change_opts: RestartForExecutableChangeOptsrestart_for_config_change_opts: RestartForConfigChangeOptslog_level_opts: LogLevelOptslog_level: Option<LogLevel>The logging level while running as daemon (as alternative to the –verbose, –debug, –quiet options on this level, and overriding the top-level logging options –log-level, –verbose, –debug, –quiet) (default: “info” for run daemon, “warn” for poll daemon)
action: DaemonModeWhether to run in the foreground, or start or stop a
daemon running in the background (or report the status
about it). Give help to see the options. evobench
defaults to the ‘hard’ actions.