Enum SubCommand

pub(crate) enum SubCommand {
    ListAll {
        opts: ListAllOpts,
    },
    List {
        opts: ListOpts,
    },
    Insert {
        method: Insert,
    },
    Poll {
        force: bool,
        quiet: bool,
        fail: bool,
        dry_run_opt: DryRunOpt,
        mode: RunMode,
    },
    Run {
        mode: RunMode,
    },
    Wd {
        subcommand: Wd,
    },
    Url {
        cd: bool,
        url: String,
    },
    Status {},
    Completions {
        shell: Shell,
    },
    ConfigFormats,
    ConfigSave {
        output_path: PathBuf,
    },
}

Variants



ListAll

Show the table of all inserted jobs, including already processed ones. This is the table that evobench insert checks to avoid duplicate inserts by default. .

Fields



List

List the jobs that are being processed (per queue)

Fields



Insert

Insert zero or more jobs, either from a complete benchmarking job description file, or using the job templates from one list from the configuration combined with zero or more commits. For automatic periodic insertion, see the poll sub-command instead. .

Fields

method: Insert


Poll

Insert jobs for new commits on branch names configured in the config option remote_branch_names_for_poll. For one-off manual insertion see insert instead. .

Fields

force: bool

Normally, the same job parameters are only inserted once, subsequent polls yielding the same commits remain no-ops. This overrides the check and inserts the found commits anyway. .

quiet: bool

Suppress printing the “inserted n jobs” message when n > 0, i.e. always be quiet.

fail: bool

Report an error if any of the given (branch or other) names do not resolve.

dry_run_opt: DryRunOpt
mode: RunMode


Run

Run the existing jobs; this takes a lock or stops with an error if the lock is already taken

Fields

mode: RunMode


Wd

Handle working directories

Fields

subcommand: Wd

The subcommand to run. Use --help after the sub-command to get a list of the allowed options there.



Url

Parse URLs to output directories

Fields

cd: bool

Open a new $SHELL (or bash) in the output directory. Default: print the path instead. .

url: String

The URL or (partial) path to parse



Status

General program status information (but also see list, wd list, list-all, run daemon status, poll daemon status)



Completions

Generate a shell completions file. (Redirect stdout to a file that is sourced from the shell.)

Fields

shell: Shell

The shell to generate the completions for.



ConfigFormats

Show the supported config format types.



ConfigSave

Re-encode the config file (with the serialization type determined by the file extension) and save it at the given path.

Fields

output_path: PathBuf