Function run_queues

pub(crate) fn run_queues<'ce>(
    run_config_bundle: RunConfigBundle,
    queues: RunQueues,
    working_directory_base_dir: Arc<WorkingDirectoryPoolBaseDir>,
    working_directory_pool: WorkingDirectoryPool,
    once: bool,
    daemon_check_exit: Option<DaemonCheckExit<'ce, RestartForExecutableOrConfigChange<Arc<ConfigFile<RunConfigOpts>>>>>,
    queue_change_signals: PollingSignalsSender,
    file_cleanup_handler: &CleanupHandler,
    _run_lock: StandaloneExclusiveFileLock,
) -> Result<RunResult>
Run through the queues forever unless once is true (in which case it returns whether a job was run), but pick up config changes; it also returns in non-once mode if the binary changes and true was given for restart_on_upgrades. Requires holding the _run_lock, the lock for executing “run” actions.